@@ -15,8 +15,8 @@
 #include "femontools.h"
 #include "femon.h"
 
-#if defined(VDRVERSNUM) && VDRVERSNUM < 10336
-#error "You don't exist! Go away! Upgrade yourself!"
+#if defined(APIVERSNUM) && APIVERSNUM < 10400
+#error "VDR-1.4.0 API version or greater is required!"
 #endif
 
 cPluginFemon::cPluginFemon()
@@ -236,6 +236,7 @@ cMenuFemonSetup::cMenuFemonSetup(void)
   themes[eFemonThemeEnigma]        = tr("Enigma");
   themes[eFemonThemeEgalsTry]      = tr("EgalsTry");
   themes[eFemonThemeDuotone]       = tr("Duotone");
+  themes[eFemonThemeSilverGreen]   = tr("SilverGreen");
 
   data = femonConfig;
   Setup();
