@@ -24,7 +24,7 @@ cFemonConfig::cFemonConfig(void)
   calcinterval   = 20;
   syslogoutput   = 0;
   showcasystem   = 0;
-#ifdef FEMON_NTSC
+#ifdef NTSC
   osdheight      = 420;
 #else
   osdheight      = 480;
@@ -96,6 +96,7 @@ const cFemonTheme femonTheme[eFemonThemeMaxNumber] =
   },
   {
     // eFemonThemeEgalsTry
+    4,          // bpp
     0xCA2B1B9E, // clrBackground
     0xDFBEBAC3, // clrTitleBackground
     0xFF280249, // clrTitleText
@@ -110,11 +111,23 @@ const cFemonTheme femonTheme[eFemonThemeMaxNumber] =
     2,          // bpp
     0x7F000000, // clrBackground
     0xFFFCFCFC, // clrTitleBackground
-    0x7F000000, // clrTitleText                                                                                                              
-    0xFFFCFCFC, // clrActiveText                                                                                                            
+    0x7F000000, // clrTitleText
+    0xFFFCFCFC, // clrActiveText
     0xFFFCFCFC, // clrInactiveText
     0xFFFC1414, // clrRed
     0xFFFCFCFC, // clrYellow
     0xFFFCFCFC, // clrGreen
   },
+  {
+    // eFemonThemeSilverGreen
+    4,          // bpp
+    0xD9526470, // clrBackground
+    0xD9293841, // clrTitleBackground
+    0xFFB3BDCA, // clrTitleText
+    0xFFCE7B00, // clrActiveText
+    0xFFB3BDCA, // clrInactiveText
+    0xFF992900, // clrRed
+    0xFFCE7B00, // clrYellow
+    0xFF336600, // clrGreen
+  },
 };
